import flux.*;
import unzip.UnzipFileAction;
import unzip.UnzipFileFactory;

/**
 * @author Copyright 2000-2009 Flux Corporation. All rights reserved.
 */
public class Main {

  /**
   * Creates a simple Flux engine.
   */
  public Main() throws Exception {

    // First, make a Flux engine.
    Factory factory = Factory.makeInstance();
    Engine engine = factory.makeEngine();

    // Flux models jobs using flow charts. Create a flow chart.
    EngineHelper helper = factory.makeEngineHelper();
    FlowChart flowChart = helper.makeFlowChart("Custom Action");

    // Our flow chart will consist of a custom action. Here is how we
    // load custom actions and triggers.

    // Create a file action to append data to a file.
    UnzipFileFactory unzipFileFactory = (UnzipFileFactory) flowChart.makeFactory("UnzipFileFactory");
    UnzipFileAction unzipFileAction = unzipFileFactory.makeFileAction("Unzip File Action");
    unzipFileAction.setZipFile("flux-7-10-3.zip");
    unzipFileAction.setDestination("extraction");

    // Create a console action to print strings to the console.
    ConsoleAction consoleAction = flowChart.makeConsoleAction("Console Action");
    consoleAction.setMessage("Finished unzipping contents of zip file.");

    // Flow from the file action to the console action.
    unzipFileAction.addFlow(consoleAction);

    // Schedule the job for immediate execution.
    engine.put(flowChart);

    // Start the engine
    engine.start();

    // Wait for the flow chart to complete
    engine.join("/", "+5m", "+2s");

    // Finally, shutdown the engine.
    engine.dispose();

  } // constructor

  public static void main(String[] args) throws Exception {
    new Main();
  } // main()
}
