package unzip;

import flux.EngineException;
import flux.FlowContext;
import fluximpl.ActionImpl;
import fluximpl.FlowChartImpl;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

/**
 * @author Copyright 2000-2009 Flux Corporation. All rights reserved.
 */
public class UnzipFileActionImpl extends ActionImpl implements UnzipFileAction {
  public static String VARIABLE_NAME = "UNZIP_FILE";

  public UnzipFileActionImpl() {
  }

  public UnzipFileActionImpl(FlowChartImpl flowChart, String name) {
    super(flowChart, name);
  }

  public Object execute(FlowContext flowContext) throws Exception {
    UnzipFileVariable var = getVariable();
    String base = var.getDestination();
    if (base == null || base.equalsIgnoreCase(".")) {
      base = "";
    }
    if (!base.equalsIgnoreCase("") && !base.endsWith("/")) {
      base += "/";
    }
    ZipFile zipFile = new ZipFile(new File(var.getZipFile()), ZipFile.OPEN_READ);
    final Enumeration<? extends ZipEntry> entries = zipFile.entries();
    byte buffer[] = new byte[51200];
    int bytesRead;
    while (entries.hasMoreElements()) {
      ZipEntry entry = entries.nextElement();
      File fileEntry = new File(base + entry.getName());
      if (entry.isDirectory()) {
        fileEntry.mkdirs();
      } else {
        InputStream in = zipFile.getInputStream(entry);
        if (!fileEntry.createNewFile()) {
          fileEntry.delete();
          fileEntry.createNewFile();
        }
        FileOutputStream out = new FileOutputStream(fileEntry);
        int offset = 0;
        while ((bytesRead = in.read(buffer)) != -1) {
          out.write(buffer, offset, bytesRead);
        }
      }
    }
    return null;
  }

  public void verify() throws EngineException {
    UnzipFileVariable var = getVariable();
    if (var.getZipFile() == null || var.getZipFile().equalsIgnoreCase("")) {
      throw new EngineException("Expected zip file path to be non-null or not empty, but it was");
    }
  }

  public String getDestination() {
    return getVariable().getDestination();
  }

  public void setDestination(String path) {
    UnzipFileVariable var = getVariable();
    var.setDestination(path);
    putVariable(var);
  }

  public String getZipFile() {
    return getVariable().getZipFile();
  }

  public void setZipFile(String path) {
    UnzipFileVariable var = getVariable();
    var.setZipFile(path);
    putVariable(var);
  }


  private UnzipFileVariable getVariable() {
    if (!getVariableManager().contains(VARIABLE_NAME)) {
      getVariableManager().put(VARIABLE_NAME, new UnzipFileVariable());
    } // if

    return (UnzipFileVariable) getVariableManager().get(VARIABLE_NAME);
  } // getVariable()

  private void putVariable(UnzipFileVariable variable) {
    getVariableManager().put(VARIABLE_NAME, variable);
  } // putVariable()
}
